==> haskell-keys-3.12.4-117.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 keys
version:              3.12.4
visibility:           public
id:                   keys-3.12.4-AkOg4ElzOjt7RzEpCwKgoO
key:                  keys-3.12.4-AkOg4ElzOjt7RzEpCwKgoO
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  fe64570be0b9781bbb0369196cdbf396
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.6.6/site-local/keys-3.12.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/keys-3.12.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/keys-3.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.4-AkOg4ElzOjt7RzEpCwKgoO
depends:
    array-0.5.6.0 base-4.18.2.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot
    containers-0.6.7 free-5.2-3fckYVSYEwRA3sQVkSQiQV
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.4-118-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 keys
version:              3.12.4
visibility:           public
id:                   keys-3.12.4-EljU96GFctJFL9dLDzZVM0
key:                  keys-3.12.4-EljU96GFctJFL9dLDzZVM0
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  24380f0aace43af9e2e4c1f5698dd1f0
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.6.6/site-local/keys-3.12.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/keys-3.12.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/keys-3.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.4-EljU96GFctJFL9dLDzZVM0
depends:
    array-0.5.6.0 base-4.18.2.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL
    containers-0.6.7 free-5.2-CP2SAI6deNWCXG1eD5QmMc
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
